# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from openupgradelib import openupgrade  # pylint: disable=W7936
from psycopg2 import sql


def scop_account_move_cg_map_values(env):

    openupgrade.map_values(
        env.cr,
        openupgrade.get_legacy_name("year"),
        "year",
        [
            (2020, "2020"),
            (2021, "2021"),
            (2022, "2022"),
        ],
        table="scop_cotisation_cg",
    )

    env.cr.execute(
        sql.SQL(
            """
                UPDATE account_move am
                SET
                    bordereau_id = ai.bordereau_id,
                    amount_cg_calculated = ai.amount_cg_calculated,
                    cotiz_quarter = cast(ai.cotiz_quarter as varchar)
                FROM account_invoice ai
                WHERE ai.id = am.old_invoice_id;
            """
        ),
    )


def scop_bordereau_map_values(env):
    openupgrade.map_values(
        env.cr,
        openupgrade.get_legacy_name("nb_quarter"),
        "nb_quarter",
        [
            (1, "1"),
            (2, "2"),
            (3, "3"),
            (4, "4"),
        ],
        table="scop_bordereau",
    )


@openupgrade.migrate()
def migrate(env, version):
    scop_account_move_cg_map_values(env)
    scop_bordereau_map_values(env)
