# © 2020 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class CotisationsConfigSettings(models.TransientModel):
    _inherit = "res.config.settings"

    is_contribution_cg = fields.Boolean(
        string="Cotisations CG Scop",
        related="company_id.is_contribution_cg",
        readonly=False,
    )
    contribution_cg_id = fields.Many2one(
        comodel_name="product.product",
        related="company_id.contribution_cg_id",
        readonly=False,
        string="Article de cotisation CG",
        domain="[('sale_ok', '=', True), ('company_id', '=', company_id)]",
    )
    contribution_fede_com_id = fields.Many2one(
        comodel_name="product.product",
        related="company_id.contribution_fede_com_id",
        readonly=False,
        string="Article de cotisation Fédé de la Com",
        domain="[('sale_ok', '=', True), ('company_id', '=', company_id)]",
    )
    journal_fede_com_id = fields.Many2one(
        comodel_name="account.journal",
        related="company_id.journal_fede_com_id",
        readonly=False,
        string="Journal Fédération de la com",
        domain="[('type', '=', 'sale')]",
    )
    contribution_fede_cae_id = fields.Many2one(
        comodel_name="product.product",
        related="company_id.contribution_fede_cae_id",
        readonly=False,
        string="Article de cotisation Fédé CAE",
        domain="[('sale_ok', '=', True), ('company_id', '=', company_id)]",
    )
    journal_fede_cae_id = fields.Many2one(
        comodel_name="account.journal",
        related="company_id.journal_fede_cae_id",
        readonly=False,
        string="Journal Fédération CAE",
        domain="[('type', '=', 'sale')]",
    )
    contribution_hdf_id = fields.Many2one(
        comodel_name="product.product",
        related="company_id.contribution_hdf_id",
        readonly=False,
        string="Article de cotisation UR HDF",
        domain="[('sale_ok', '=', True), ('company_id', '=', company_id)]",
    )
    journal_ur_hdf_id = fields.Many2one(
        comodel_name="account.journal",
        related="company_id.journal_ur_hdf_id",
        readonly=False,
        string="Journal UR HDF",
        domain="[('type', '=', 'sale')]",
    )
    contribution_med_id = fields.Many2one(
        comodel_name="product.product",
        related="company_id.contribution_med_id",
        readonly=False,
        string="Article de cotisation UR Méditerranée",
        domain="[('sale_ok', '=', True), ('company_id', '=', company_id)]",
    )
    journal_ur_med_id = fields.Many2one(
        comodel_name="account.journal",
        related="company_id.journal_ur_med_id",
        readonly=False,
        string="Journal UR Med",
        domain="[('type', '=', 'sale')]",
    )

    @api.onchange("is_contribution")
    def _onchange_is_contribution_cg(self):
        if not self.is_contribution:
            self.is_contribution_cg = False
