# © 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).


from odoo import _, api, fields, models
from odoo.exceptions import ValidationError


class BordereauVersion(models.Model):
    _name = "scop.bordereau.version"
    _description = "Historique des versions des bordereaux des cotisations CG"

    bordereau_id = fields.Many2one(
        comodel_name="scop.bordereau",
        string="Bordereau de rattachement",
        required=True,
        readonly=True,
        ondelete="cascade",
    )
    version = fields.Integer("Version du bordereau", readonly=True)
    comment = fields.Char(string="Motif")
    liasse_fiscale_id_old = fields.Many2one(
        comodel_name="scop.liasse.fiscale",
        string="Ancienne liasse fiscale",
        ondelete="set null",
        readonly=True,
    )
    type_assiette = fields.Selection(
        string="Ancien type d'assiette",
        selection=[
            ("ca", "CA"),
            ("va", "VA"),
        ],
        readonly=True,
    )
    date = fields.Date("Date", readonly=True)
    montant_assiette = fields.Integer(string="Ancien montant assiette", readonly=True)
    company_currency_id = fields.Many2one(related="bordereau_id.company_currency_id")
    amount_total_cotiz = fields.Monetary(
        string="Ancien montant cotisation",
        currency_field="company_currency_id",
        readonly=True,
    )
    state = fields.Selection(
        [("new", "Brouillon"), ("validated", "Validée")],
        string="Statut",
        default="new",
        readonly=True,
    )

    # ------------------------------------------------------
    # Constrain Functions
    # ------------------------------------------------------
    @api.constrains("state")
    def check_unique_state_new(self):
        """Une seule version en brouillon par bordereau"""
        if (
            len(
                self.bordereau_id.bordereau_version_ids.filtered(
                    lambda v: v.state == "new"
                )
            )
            > 1
        ):
            raise ValidationError(
                _(
                    "Vous devez valider ou annuler les versions de bordereaux en "
                    "cours de modification avant de créer une nouvelle version !"
                )
            )
