# Copyright 2021 Le Filament
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl).

from odoo import fields, models


class ScopBordereauChangePaymentMode(models.TransientModel):
    _name = "scop.bordereau.change.payment.mode.wizard"
    _description = "Changement de mode de paiement"

    bordereau_id = fields.Many2one(
        comodel_name="scop.bordereau",
        string="Bordereau",
        readonly=True,
    )
    payment_mode_id = fields.Many2one(
        comodel_name="account.payment.mode",
        string="Nouveau mode de paiment",
    )
    change_type = fields.Selection(
        string="Type d'affectation",
        selection=[
            (
                "punctual",
                "Définir pour les échéances non payées de ce " "bordereau uniquement",
            ),
            ("all", "Définir pour toutes les prochaines échéances"),
        ],
        default="punctual",
        required=False,
    )

    # ------------------------------------------------------
    # Action Button
    # ------------------------------------------------------
    def action_change_payment_mode(self):
        bordereau_id = self.bordereau_id
        # Link new liasse fiscale to bordereau
        if self.change_type == "all":
            bordereau_id.partner_id.update(
                {
                    "customer_payment_mode_id": self.payment_mode_id.id,
                }
            )
        bordereau_id.update(
            {
                "payment_mode_id": self.payment_mode_id.id,
            }
        )
        bordereau_id.invoice_ids.update(
            {
                "payment_mode_id": self.payment_mode_id.id,
            }
        )
        contrib_cg_journal = self.env.company.contribution_journal_id
        contrib_ur_fede_journal = (
            self.env.company.contribution_ur_or_fede_journal_id
        )
        move_line_ids = self.env["account.move.line"].search(
            [
                ("partner_id", "=", self.bordereau_id.partner_id.id),
                (
                    "journal_id",
                    "in",
                    (contrib_cg_journal.id, contrib_ur_fede_journal.id),
                ),
                ("full_reconcile_id", "=", False),
                ("balance", "!=", 0),
                ("account_id.reconcile", "=", True),
                ("account_id.internal_type", "=", "receivable"),
            ]
        )
        move_line_ids.update(
            {
                "payment_mode_id": self.payment_mode_id.id,
            }
        )
        return {"type": "ir.actions.act_window_close"}
